// 企业路由信息
import Layout from '@/layout/enterprise.vue'

const enterprise = [
  {
    path: '/enterprise', // 企业账号登录时，缺省进去企业路由，防止用户在地址栏直接输入地址访问其他页面（不可删，permission中用到）
    show: true,
    redirect: '/recruit/enterprise',
  },
  // { 不能重定向，用于切换企业登录拦截
  //   path: '/enterpriseVerification', // 切换企业后先校验是否具备必填信息
  //   show: true,
  //   meta: {
  //     loginType: 'enterprise'
  //   }
  //   // redirect: '/enterprise',
  // },
  {
    path: '/recruit/enterprise',
    show: true,
    redirect: '/recruit/enterprise/position',
  },
  {
    path: '/recruit/enterprise/position',
    component: Layout,
    name: 'jobManagement',
    meta: {
      title: '职位管理',
      enName: 'Job Management',
      icon: 'mdi-format-list-bulleted-square'
    },
    children: [
      {
        path: '/recruit/enterprise/position',
        show: true,
        meta: {
          title: '职位列表',
          enName: 'Job list'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/index.vue')
      },
      {
        path: '/recruit/enterprise/position/add',
        show: true,
        meta: {
          title: '新增职位'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/recruit/enterprise/position/edit',
        show: true,
        meta: {
          title: '职位编辑'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/talentRecruitment',
    redirect: '/recruit/enterprise/search',
    component: Layout,
    name: 'Talent Recruitment',
    meta: {
      title: '人才招聘',
      enName: 'Talent Recruitment',
      icon: 'mdi-account-settings-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/search',
        meta: {
          title: '找人',
          enName: 'Search People',
        },
        component: () => import('@/views/recruit/enterprise/search/index.vue')
      },
      {
        path: '/recruit/enterprise/chatTools',
        meta: {
          title: '沟通',
          enName: 'Communication',
        },
        component: () => import('@/views/recruit/enterprise/chatTools/index.vue')
      },
      {
        path: '/recruit/enterprise/resume',
        meta: {
          title: '简历',
          enName: 'Resume'
        },
        component: () => import('@/views/recruit/enterprise/resume/index.vue')
      },
      {
        path: '/recruit/enterprise/interviewManagement',
        meta: {
          title: '面试',
          enName: 'Interview'
        },
        component: () => import('@/views/recruit/enterprise/interviewManagement/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/talentPool',
    component: Layout,
    name: 'Elite Reserve',
    meta: {
      title: '精英储备',
      enName: 'Job Management',
      icon: 'mdi-account-supervisor-circle'
    },
    children: [
      {
        path: '/recruit/enterprise/talentPool',
        show: true,
        component: () => import('@/views/recruit/enterprise/talentPool/index.vue')
      },
      {
        path: '/recruit/enterprise/talentPool/details/:id',
        show: true, // 侧边栏不展示
        component: () => import('@/views/recruit/enterprise/talentPool/components/details'),
        name: 'talentPoolDetails',
        meta: {
          title: '人才详情',
          hideSide: true
        }
      },
    ]
  },
  {
    path: '/recruit/enterprise/hirePosition',
    component: Layout,
    name: 'crowdSourcing',
    meta: {
      title: '全员猎聘',
      enName: 'Crowd Sourcing',
      icon: 'mdi-account-star-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/hirePosition',
        show: true,
        meta: {
          title: '全员猎聘'
        },
        component: () => import('@/views/recruit/enterprise/hirePosition/index.vue')
      },
      {
        path: '/recruit/enterprise/hirePosition/add',
        show: true,
        meta: {
          title: '新增职位'
        },
        component: () => import('@/views/recruit/enterprise/hirePosition/components/add.vue')
      },
      {
        path: '/recruit/enterprise/hirePosition/edit',
        show: true,
        meta: {
          title: '职位编辑'
        },
        component: () => import('@/views/recruit/enterprise/hirePosition/components/add.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/talentMap',
    component: Layout,
    name: 'Talent Map',
    meta: {
      title: '人才地图',
      enName: 'Talent Map',
      icon: 'mdi-map-check'
    },
    children: [
      {
        path: '/recruit/enterprise/talentMap',
        show: true,
        component: () => import('@/views/recruit/enterprise/talentMap/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/statistics/overallAnalysis',
    component: Layout,
    name: 'enterpriseStatistics',
    meta: {
      title: '统计分析',
      enName: 'Statistics',
      icon: 'mdi-chart-arc'
    },
    children: [
      {
        path: '/recruit/enterprise/statistics/overallAnalysis',
        show: true,
        component: () => import('@/views/recruit/enterprise/statistics/overallAnalysis.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/systemManagement',
    component: Layout,
    redirect: '/recruit/enterprise/systemManagement/userManagement',
    name: 'systemManagement',
    meta: {
      title: '系统管理',
      enName: 'system Management',
      icon: 'mdi-cog-outline',
      isAdmin: true // 企业管理员菜单
    },
    children: [
      // 集团
      {
        path: '/recruit/enterprise/systemManagement/groupAccount',
        meta: {
          title: '集团账户',
          enName: 'Group Account '
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/groupAccount/index.vue')
      },
      // 邀请生成链接页面(非邀请页)
      {
        path: '/recruit/enterprise/systemManagement/groupAccount/invite/:type',
        show: true,
        meta: {
          hideSide: true,
          title: '邀请',
          enName: 'Invite'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/groupAccount/invite.vue')
      },
      // {
      //   path: '/recruit/enterprise/systemManagement/userManagement',
      //   meta: {
      //     title: '用户管理',
      //     enName: 'User Management '
      //   },
      //   component: () => import('@/views/recruit/enterprise/systemManagement/userManagement/index.vue')
      // },

      // 岗位管理 
      // {
      //   path: '/recruit/enterprise/systemManagement/postManagement',
      //   meta: {
      //     title: '岗位管理',
      //     enName: 'Post Management '
      //   },
      //   component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/index.vue')
      // },
      {
        path: '/recruit/enterprise/systemManagement/postManagement/add',
        show: true,
        meta: {
          title: '新增岗位'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/save.vue')
      },
      {
        path: '/recruit/enterprise/systemManagement/postManagement/edit',
        show: true,
        meta: {
          title: '岗位编辑'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/save.vue')
      },
      // 企业信息 
      {
        path: '/recruit/enterprise/entInfoSetting',
        meta: {
          title: '企业信息',
          enName: 'Group Account '
        },
        component: () => import('@/views/recruit/enterprise/entInfoSetting/index.vue')
      },
      // 员工信息 
      {
        path: '/recruit/enterprise/staffInfoSetting',
        meta: {
          title: '员工信息',
          enName: 'Group Account '
        },
        component: () => import('@/views/recruit/enterprise/staffInfoSetting/index.vue')
      },
      {
        path: '/recruit/enterprise/staffChangePassword',
        show: true,
        meta: {
          title: '修改登录密码',
        },
        component: () => import('@/views/recruit/enterprise/staffChangePassword/index.vue')
      },
    ]
  },
  {
    component: Layout,
    path: '/recruit/enterprise/financialCenter',
    redirect: '/recruit/enterprise/membershipPackage',
    name: 'enterpriseMemberCenter',
    meta: {
      title: '财务中心',
      enName: 'system Management',
      icon: 'mdi-account',
      // isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/recruit/enterprise/membershipPackage',
        meta: {
          title: '会员权益',
          enName: 'Membership Benefits'
        },
        component: () => import('@/views/recruit/enterprise/membershipPackage/index.vue')
      },
      {
        path: '/recruit/enterprise/tradingOrder',
        meta: {
          title:'订单管理',
          enName: 'Order management'
        },
        component: () => import('@/views/recruit/enterprise/tradingOrder/index.vue')
      },
      {
        path: '/recruit/enterprise/invoiceManagement',
        meta: {
          title: '发票抬头管理',
          enName: 'Invoice Management '
        },
        component: () => import('@/views/recruit/enterprise/invoiceManagement/index.vue')
      }
    ]
  }
]
export default enterprise